#include "asm86.h"
#include "ti86asm.inc"

.org _asm_exec_ram

     call _clrLCD                   ; clear home screen
     call _runindicoff              ; turn off run indicator
     call _flushallmenus            ; close any menus
     ld bc,$0000                    ; (b,c) = (y,x)
     ld hl,TextToBeSmallScrolled    ; load bunch of text to display
;     call DispSmallScrollingText    ; now, display it!!
     ;jp _clrLCD                     ; clear LCD screen and return!

;//////////////////////////////////////////////////////////////////////////////////
;//Input:
;//////////////////////////////////////////////////////////////////////////////////
;   register bc  -> (y,x) coordinates
;   register hl  -> text to be displayed
;   line must end with ",0" to be recognized as new line character
;   ending line must end with",214" to be recognized as end of text
;   routine should be called, it will return when it finds the end of text 
;//////////////////////////////////////////////////////////////////////////////////
;//Output:
;//////////////////////////////////////////////////////////////////////////////////
;   displays text scrolling in small font
;//////////////////////////////////////////////////////////////////////////////////
;   ----To use, satisfy Input requirements, then:
;       call DispSmallScrollingText
;   31 instructions, 60 bytes, 322 cycles
;//////////////////////////////////////////////////////////////////////////////////

DispSmallScrollingText:
     ld (_penCol),bc                ; load those coordinates into (y,x)
DispSmallScrollingText01:
     ld a,(hl)                      ; load a character into "register a"
     or a \ jr z,IncCharacterYCoord ; if that letter is 0, increase the y coord and end line
     cp 214 \ ret z                 ; if it is the end of text character, return to where call was made from
IncCharacterAndDisplay:
     inc hl                         ; load next character into hl
     call _vputmap                  ; display that character in small sfont
     ld a,5                         ; load the speed difference between each letter being displayed
CharacterDelay:
     halt                           ; halt and do nothing
     dec a \ jr nz,CharacterDelay   ; decrease "register a" and repeat loop until it reaches 0
     jr DispSmallScrollingText01    ; start the cycle all over agains

IncCharacterYCoord:
     push hl \ push af              ; save "register hl" and "register"af"
     ld a,b                         ; load into "register a" the y-coordinate
     add a,8                        ; add 8 to it
     cp 57 \ call p,ScrollAndHold   ; if end of screen (y > 57), scroll screen and hold that coordinate
     ld b,a                         ; store the y-coordinate into "register b"
     ld (_penCol),bc                ; load y,x coordinates into the small font coordinates
     pop af \ pop hl                ; destroy "register hl" and "register hl" to revert to old values
     jr IncCharacterAndDisplay      ; now, increment next character and display it

ScrollAndHold:
     ld a,7                         ; "register a" contains 7 lines to scroll (loop is going to run 7 times)
ScrollAndHoldLoop:                  ; change the number 7 to something else if you want to.
     push bc                        ; save (y,x) coordinates to stack
     ld hl,$fc00+16                 ; 16 = 1 line of pixels to be scrolled up from bottom on the video page
     ld de,$fc00                    ; load into "register de" what video page to scroll
     ld bc,1008                     ; 1024 - 16 = 1008, must be loaded
     ldir                           ; subtract "register bc" and increment "registers hl & de" until bc=0
     pop bc                         ; reload (y,x) coordinates from the stack
     dec a \ jr nz,ScrollAndHoldLoop; check to see if a = 0, if it isn't repeat loop
     ld a,57                        ; load into a whatever fixed y-coordinate should be after scrolling
     ret                            ; return to where call was made from
        
TextToBeSmallScrolled:
;replace the text below with your text
    .db "This demonstrates the small font",0
    .db "scrolling routine. It can be used",0
    .db "for title screens, endings, talking,",0
    .db "etc.",0
    .db "This is a test",0
    .db "So, is this",0
    .db "1234567890"0
    .db "All your bases are belong to us!!",0
    .db "I hope you like it",0
    .db "coded by Haroon I",0
    .db "haroon4@hotmail.com",0
    .db "http://haroon4.ifreepages.com",0
    .db "12/15/2004",214

.end